.phanterpwa-snippet-centralizer
    min-height: 20px
    height: 20px
    overflow: hidden
    transition: height 1s ease


.phanterpwa-snippet-promooption
    text-decoration: none
    color: inherit
    height: 300px
    overflow: hidden
    .promo-icon_and_title
        &>i
            font-size: 80pt
        .phanterpwa-snippet-icombine
            .icombine-container
                font-size: 80pt
                margin-top: -0.1em
    &.link
        &:hover
            .promo-content
                color: rgba(0, 0, 0, 0.8)


.phanterpwa-snippet-icombine
    .icombine-container
        position: relative
        .icombine-container-first
            font-size: 0.9em
        .icombine-container-last
            font-size: 0.3em
            position: absolute

